import { ApiKeyDTO, CreateApiKeyDTO } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to create API keys.
 */
export type CreateApiKeysWorkflowInput = {
    /**
     * The API keys to create.
     */
    api_keys: CreateApiKeyDTO[];
};
/**
 * The created API keys.
 */
export type CreateApiKeysWorkflowOutput = ApiKeyDTO[];
export declare const createApiKeysWorkflowId = "create-api-keys";
/**
 * This workflow creates one or more API keys, which can be secret or publishable. It's used by the
 * [Create API Key Admin API Route](https://docs.medusajs.com/api/admin#api-keys_postapikeys).
 *
 * You can use this workflow within your customizations or your own custom workflows, allowing you to
 * create API keys within your custom flows.
 *
 * @example
 * const { result } = await createApiKeysWorkflow(container)
 * .run({
 *   input: {
 *     api_keys: [
 *       {
 *         type: "publishable",
 *         title: "Storefront",
 *         created_by: "user_123"
 *       }
 *     ]
 *   }
 * })
 *
 * @summary
 *
 * Create secret or publishable API keys.
 */
export declare const createApiKeysWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<CreateApiKeysWorkflowInput, ApiKeyDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"apiKeysCreated", {
    apiKeys: (ApiKeyDTO | WorkflowData<ApiKeyDTO>)[] & ApiKeyDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<ApiKeyDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<ApiKeyDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<ApiKeyDTO[]>;
}, unknown>]>;
//# sourceMappingURL=create-api-keys.d.ts.map