"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCartCreditLinesWorkflow = exports.createCartCreditLinesWorkflowId = void 0;
const utils_1 = require("@medusajs/framework/utils");
const workflows_sdk_1 = require("@medusajs/framework/workflows-sdk");
const create_entities_1 = require("../../common/steps/create-entities");
exports.createCartCreditLinesWorkflowId = "create-cart-credit-lines";
/**
 * This workflow creates one or more credit lines for a cart.
 *
 * @example
 * const { result } = await createCartCreditLinesWorkflow(container)
 * .run({
 *   input: {
 *     cart_id: "cart_123",
 *     amount: 10,
 *     reference: "payment",
 *     reference_id: "payment_123",
 *     metadata: {
 *       key: "value",
 *     },
 *   }
 * })
 */
exports.createCartCreditLinesWorkflow = (0, workflows_sdk_1.createWorkflow)(exports.createCartCreditLinesWorkflowId, (input) => {
    const creditLines = (0, create_entities_1.createEntitiesStep)({
        moduleRegistrationName: utils_1.Modules.CART,
        invokeMethod: "createCreditLines",
        compensateMethod: "deleteCreditLines",
        data: input,
    });
    return new workflows_sdk_1.WorkflowResponse(creditLines);
});
//# sourceMappingURL=create-cart-credit-lines.js.map