import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The cart ownership transfer details.
 */
export type TransferCartCustomerWorkflowInput = {
    /**
     * The cart's ID.
     */
    id: string;
    /**
     * The ID of the customer to transfer the cart to.
     */
    customer_id: string;
};
export declare const transferCartCustomerWorkflowId = "transfer-cart-customer";
/**
 * This workflow transfers a cart's customer ownership to another customer. It's useful if a customer logs in after
 * adding the items to their cart, allowing you to transfer the cart's ownership to the logged-in customer. This workflow is used
 * by the [Set Cart's Customer Store API Route](https://docs.medusajs.com/api/store#carts_postcartsidcustomer).
 *
 * You can use this workflow within your own customizations or custom workflows, allowing you to set the cart's customer within your custom flows.
 *
 * @example
 * const { result } = await transferCartCustomerWorkflow(container)
 * .run({
 *   input: {
 *     id: "cart_123",
 *     customer_id: "cus_123"
 *   }
 * })
 *
 * @summary
 *
 * Refresh a cart's payment collection details.
 *
 * @property hooks.validate - This hook is executed before all operations. You can consume this hook to perform any custom validation. If validation fails, you can throw an error to stop the workflow execution.
 */
export declare const transferCartCustomerWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<TransferCartCustomerWorkflowInput, undefined, [import("@medusajs/framework/workflows-sdk").Hook<"validate", {
    input: WorkflowData<TransferCartCustomerWorkflowInput>;
    cart: any;
}, unknown>]>;
//# sourceMappingURL=transfer-cart-customer.d.ts.map