import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The details of the customers to delete.
 */
export type DeleteCustomersWorkflowInput = {
    /**
     * The IDs of the customers to delete.
     */
    ids: string[];
};
export declare const deleteCustomersWorkflowId = "delete-customers";
/**
 * This workflow deletes one or more customers. It's used by the
 * {@link removeCustomerAccountWorkflow}.
 *
 * You can use this workflow within your customizations or your own custom workflows, allowing you to
 * delete customers in your custom flows.
 *
 * @example
 * const { result } = await deleteCustomersWorkflow(container)
 * .run({
 *   input: {
 *     ids: [
 *       "cus_123",
 *     ]
 *   }
 * })
 *
 * @summary
 *
 * Delete one or more customers.
 *
 * @property hooks.customersDeleted - This hook is executed after the customers are deleted. You can consume this hook to perform custom actions.
 */
export declare const deleteCustomersWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<DeleteCustomersWorkflowInput, never, [import("@medusajs/framework/workflows-sdk").Hook<"customersDeleted", {
    ids: (string[] | WorkflowData<string[]>) & string[];
}, unknown>]>;
//# sourceMappingURL=delete-customers.d.ts.map