import { FulfillmentDTO, OrderClaimDTO, OrderWorkflow, ReturnDTO } from "@medusajs/framework/types";
/**
 * The data to validate the cancelation of a confirmed order claim.
 */
export type CancelClaimValidateOrderStepInput = {
    /**
     * The order claim's details.
     */
    orderClaim: OrderClaimDTO;
    /**
     * The order claim's return details.
     */
    orderReturn: ReturnDTO & {
        fulfillments: FulfillmentDTO[];
    };
    /**
     * The cancelation details.
     */
    input: OrderWorkflow.CancelOrderClaimWorkflowInput;
};
/**
 * This step validates that a confirmed claim can be canceled. If the claim is canceled,
 * or the claim's fulfillments are not canceled, the step will throw an error.
 *
 * :::note
 *
 * You can retrieve an order claim's details using [Query](https://docs.medusajs.com/learn/fundamentals/module-links/query),
 * or [useQueryGraphStep](https://docs.medusajs.com/resources/references/medusa-workflows/steps/useQueryGraphStep).
 *
 * :::
 *
 * @example
 * const data = cancelClaimValidateOrderStep({
 *   orderClaim: {
 *     id: "claim_123",
 *     // other order claim details...
 *   },
 *   input: {
 *     claim_id: "claim_123",
 *   }
 * })
 */
export declare const cancelClaimValidateOrderStep: import("@medusajs/framework/workflows-sdk").StepFunction<CancelClaimValidateOrderStepInput, unknown>;
export declare const cancelOrderClaimWorkflowId = "cancel-claim";
/**
 * This workflow cancels a confirmed order claim. It's used by the
 * [Cancel Claim API Route](https://docs.medusajs.com/api/admin#claims_postclaimsidcancel).
 *
 * You can use this workflow within your customizations or your own custom workflows, allowing you to cancel a claim
 * for an order in your custom flows.
 *
 * @example
 * const { result } = await cancelOrderClaimWorkflow(container)
 * .run({
 *   input: {
 *     claim_id: "claim_123",
 *   }
 * })
 *
 * @summary
 *
 * Cancel a confirmed order claim.
 */
export declare const cancelOrderClaimWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<OrderWorkflow.CancelOrderClaimWorkflowInput, unknown, any[]>;
//# sourceMappingURL=cancel-claim.d.ts.map