import { AdditionalData } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The orders to complete, along with custom data that's passed to the workflow's hooks.
 */
export type CompleteOrdersWorkflowInput = {
    /**
     * The IDs of the orders to complete.
     */
    orderIds: string[];
} & AdditionalData;
export declare const completeOrderWorkflowId = "complete-order-workflow";
/**
 * This workflow marks one or more orders as completed. It's used by the [Complete Cart Admin API Route](https://docs.medusajs.com/api/admin#orders_postordersidcomplete).
 *
 * This workflow has a hook that allows you to perform custom actions on the completed orders. For example, you can pass under `additional_data` custom data that
 * allows you to update custom data models linked to the orders.
 *
 * You can also use this workflow within your customizations or your own custom workflows, allowing you to wrap custom logic around order completion.
 *
 * @example
 * const { result } = await completeOrderWorkflow(container)
 * .run({
 *   input: {
 *     orderIds: ["order_1", "order_2"],
 *     additional_data: {
 *       send_webhook: true,
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Complete one or more orders.
 *
 * @property hooks.ordersCompleted - This hook is executed after the orders are completed. You can consume this hook to perform custom actions on the completed orders.
 */
export declare const completeOrderWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<CompleteOrdersWorkflowInput, import("@medusajs/framework/types").OrderDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"ordersCompleted", {
    orders: (import("@medusajs/framework/types").OrderDTO | WorkflowData<import("@medusajs/framework/types").OrderDTO>)[] & import("@medusajs/framework/types").OrderDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<import("@medusajs/framework/types").OrderDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<import("@medusajs/framework/types").OrderDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<import("@medusajs/framework/types").OrderDTO[]>;
    additional_data: ((Record<string, unknown> | WorkflowData<Record<string, unknown> | undefined>) & Record<string, unknown>) | undefined;
}, unknown>]>;
//# sourceMappingURL=complete-orders.d.ts.map