import { AdditionalData, ProductTypes } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to create one or more product tags, along with custom data that's passed to the workflow's hooks.
 */
export type CreateProductTagsWorkflowInput = {
    /**
     * The product tags to create.
     */
    product_tags: ProductTypes.CreateProductTagDTO[];
} & AdditionalData;
export declare const createProductTagsWorkflowId = "create-product-tags";
/**
 * This workflow creates one or more product tags. It's used by the
 * [Create Product Tag Admin API Route](https://docs.medusajs.com/api/admin#product-tags_postproducttags).
 *
 * This workflow has a hook that allows you to perform custom actions on the created product tags. For example, you can pass under `additional_data` custom data that
 * allows you to create custom data models linked to the product tags.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product-tag creation.
 *
 * @example
 * const { result } = await createProductTagsWorkflow(container)
 * .run({
 *   input: {
 *     product_tags: [
 *       {
 *         value: "clothing"
 *       }
 *     ],
 *     additional_data: {
 *       erp_id: "123"
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Create one or more product tags.
 *
 * @property hooks.productTagsCreated - This hook is executed after the product tags are created. You can consume this hook to perform custom actions on the created product tags.
 */
export declare const createProductTagsWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<CreateProductTagsWorkflowInput, ProductTypes.ProductTagDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"productTagsCreated", {
    product_tags: (ProductTypes.ProductTagDTO | WorkflowData<ProductTypes.ProductTagDTO>)[] & ProductTypes.ProductTagDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<ProductTypes.ProductTagDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<ProductTypes.ProductTagDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<ProductTypes.ProductTagDTO[]>;
    additional_data: ((Record<string, unknown> | WorkflowData<Record<string, unknown> | undefined>) & Record<string, unknown>) | undefined;
}, unknown>]>;
//# sourceMappingURL=create-product-tags.d.ts.map