import { AdditionalData, ProductTypes } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to create one or more product types, along with custom data that's passed to the workflow's hooks.
 */
export type CreateProductTypesWorkflowInput = {
    /**
     * The product types to create.
     */
    product_types: ProductTypes.CreateProductTypeDTO[];
} & AdditionalData;
export declare const createProductTypesWorkflowId = "create-product-types";
/**
 * This workflow creates one or more product types. It's used by the
 * [Create Product Type Admin API Route](https://docs.medusajs.com/api/admin#product-types_postproducttypes).
 *
 * This workflow has a hook that allows you to perform custom actions on the created product types. For example, you can pass under `additional_data` custom data that
 * allows you to create custom data models linked to the product types.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product-type creation.
 *
 * @example
 * const { result } = await createProductTypesWorkflow(container)
 * .run({
 *   input: {
 *     product_types: [
 *       {
 *         value: "clothing"
 *       }
 *     ],
 *     additional_data: {
 *       erp_id: "123"
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Create one or more product types.
 *
 * @property hooks.productTypesCreated - This hook is executed after the product types are created. You can consume this hook to perform custom actions on the created product types.
 */
export declare const createProductTypesWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<CreateProductTypesWorkflowInput, ProductTypes.ProductTypeDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"productTypesCreated", {
    product_types: (ProductTypes.ProductTypeDTO | WorkflowData<ProductTypes.ProductTypeDTO>)[] & ProductTypes.ProductTypeDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<ProductTypes.ProductTypeDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<ProductTypes.ProductTypeDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<ProductTypes.ProductTypeDTO[]>;
    additional_data: ((Record<string, unknown> | WorkflowData<Record<string, unknown> | undefined>) & Record<string, unknown>) | undefined;
}, unknown>]>;
//# sourceMappingURL=create-product-types.d.ts.map