import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to delete one or more product tags.
 */
export type DeleteProductTagsWorkflowInput = {
    /**
     * The IDs of the tags to delete.
     */
    ids: string[];
};
export declare const deleteProductTagsWorkflowId = "delete-product-tags";
/**
 * This workflow deletes one or more product tags. It's used by the
 * [Delete Product Tags Admin API Route](https://docs.medusajs.com/api/admin#product-tags_deleteproducttagsid).
 *
 * This workflow has a hook that allows you to perform custom actions after the product tags are deleted. For example,
 * you can delete custom records linked to the product tags.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product-tag deletion.
 *
 * @example
 * const { result } = await deleteProductTagsWorkflow(container)
 * .run({
 *   input: {
 *     ids: ["ptag_123"],
 *   }
 * })
 *
 * @summary
 *
 * Delete one or more product tags.
 *
 * @property hooks.productTagsDeleted - This hook is executed after the tags are deleted. You can consume this hook to perform custom actions on the deleted tags.
 */
export declare const deleteProductTagsWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<DeleteProductTagsWorkflowInput, never, [import("@medusajs/framework/workflows-sdk").Hook<"productTagsDeleted", {
    ids: (string[] | WorkflowData<string[]>) & string[];
}, unknown>]>;
//# sourceMappingURL=delete-product-tags.d.ts.map