import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to delete one or more products.
 */
export type DeleteProductsWorkflowInput = {
    /**
     * The IDs of the products to delete.
     */
    ids: string[];
};
export declare const deleteProductsWorkflowId = "delete-products";
/**
 * This workflow deletes one or more products. It's used by the
 * [Delete Products Admin API Route](https://docs.medusajs.com/api/admin#products_deleteproductsid).
 *
 * This workflow has a hook that allows you to perform custom actions after the products are deleted. For example,
 * you can delete custom records linked to the products.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product deletion.
 *
 * @example
 * const { result } = await deleteProductsWorkflow(container)
 * .run({
 *   input: {
 *     ids: ["product_123"],
 *   }
 * })
 *
 * @summary
 *
 * Delete one or more products.
 *
 * @property hooks.productsDeleted - This hook is executed after the products are deleted. You can consume this hook to perform custom actions on the deleted products.
 */
export declare const deleteProductsWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<DeleteProductsWorkflowInput, never, [import("@medusajs/framework/workflows-sdk").Hook<"productsDeleted", {
    ids: (string[] | WorkflowData<string[]>) & string[];
}, unknown>]>;
//# sourceMappingURL=delete-products.d.ts.map