import { AdditionalData, ProductTypes } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to update one or more product tags, along with custom data that's passed to the workflow's hooks.
 */
export type UpdateProductTagsWorkflowInput = {
    /**
     * The filters to select the product tags to update.
     */
    selector: ProductTypes.FilterableProductTypeProps;
    /**
     * The data to update in the product tags.
     */
    update: ProductTypes.UpdateProductTypeDTO;
} & AdditionalData;
export declare const updateProductTagsWorkflowId = "update-product-tags";
/**
 * This workflow updates one or more product tags. It's used by the
 * [Update Product Tag Admin API Route](https://docs.medusajs.com/api/admin#product-tags_postproducttagsid).
 *
 * This workflow has a hook that allows you to perform custom actions on the updated product tags. For example, you can pass under `additional_data` custom data that
 * allows you to update custom data models linked to the product tags.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product-tag updates.
 *
 * @example
 * const { result } = await updateProductTagsWorkflow(container)
 * .run({
 *   input: {
 *     selector: {
 *       id: "pcol_123"
 *     },
 *     update: {
 *       value: "clothing"
 *     },
 *     additional_data: {
 *       erp_id: "123"
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Update one or more product tags.
 *
 * @property hooks.productTagsUpdated - This hook is executed after the product tags are updated. You can consume this hook to perform custom actions on the updated product tags.
 */
export declare const updateProductTagsWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<UpdateProductTagsWorkflowInput, ProductTypes.ProductTagDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"productTagsUpdated", {
    product_tags: (ProductTypes.ProductTagDTO | WorkflowData<ProductTypes.ProductTagDTO>)[] & ProductTypes.ProductTagDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<ProductTypes.ProductTagDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<ProductTypes.ProductTagDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<ProductTypes.ProductTagDTO[]>;
    additional_data: ((Record<string, unknown> | WorkflowData<Record<string, unknown> | undefined>) & Record<string, unknown>) | undefined;
}, unknown>]>;
//# sourceMappingURL=update-product-tags.d.ts.map