import { AdditionalData, ProductTypes } from "@medusajs/framework/types";
import { WorkflowData } from "@medusajs/framework/workflows-sdk";
/**
 * The data to update one or more product types, along with custom data that's passed to the workflow's hooks.
 */
type UpdateProductTypesWorkflowInput = {
    /**
     * The filters to select the product types to update.
     */
    selector: ProductTypes.FilterableProductTypeProps;
    /**
     * The data to update in the product types.
     */
    update: ProductTypes.UpdateProductTypeDTO;
} & AdditionalData;
export declare const updateProductTypesWorkflowId = "update-product-types";
/**
 * This workflow updates one or more product types. It's used by the
 * [Update Product Type Admin API Route](https://docs.medusajs.com/api/admin#product-types_postproducttypesid).
 *
 * This workflow has a hook that allows you to perform custom actions on the updated product types. For example, you can pass under `additional_data` custom data that
 * allows you to update custom data models linked to the product types.
 *
 * You can also use this workflow within your own custom workflows, allowing you to wrap custom logic around product-type updates.
 *
 * @example
 * const { result } = await updateProductTypesWorkflow(container)
 * .run({
 *   input: {
 *     selector: {
 *       id: "ptyp_123"
 *     },
 *     update: {
 *       value: "clothing"
 *     },
 *     additional_data: {
 *       erp_id: "123"
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Update one or more product types.
 *
 * @property hooks.productTypesUpdated - This hook is executed after the product types are updated. You can consume this hook to perform custom actions on the updated product types.
 */
export declare const updateProductTypesWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<UpdateProductTypesWorkflowInput, ProductTypes.ProductTypeDTO[], [import("@medusajs/framework/workflows-sdk").Hook<"productTypesUpdated", {
    product_types: (ProductTypes.ProductTypeDTO | WorkflowData<ProductTypes.ProductTypeDTO>)[] & ProductTypes.ProductTypeDTO[] & import("@medusajs/framework/workflows-sdk").WorkflowDataProperties<ProductTypes.ProductTypeDTO[]> & {
        config(config: {
            name?: string;
        } & Omit<import("@medusajs/orchestration").TransactionStepsDefinition, "next" | "uuid" | "action">): WorkflowData<ProductTypes.ProductTypeDTO[]>;
    } & import("@medusajs/framework/workflows-sdk").StepFunctionReturnConfig<ProductTypes.ProductTypeDTO[]>;
    additional_data: ((Record<string, unknown> | WorkflowData<Record<string, unknown> | undefined>) & Record<string, unknown>) | undefined;
}, unknown>]>;
export {};
//# sourceMappingURL=update-product-types.d.ts.map