"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteRegionsWorkflow = exports.deleteRegionsWorkflowId = void 0;
const utils_1 = require("@medusajs/framework/utils");
const workflows_sdk_1 = require("@medusajs/framework/workflows-sdk");
const emit_event_1 = require("../../common/steps/emit-event");
const remove_remote_links_1 = require("../../common/steps/remove-remote-links");
const steps_1 = require("../steps");
exports.deleteRegionsWorkflowId = "delete-regions";
/**
 * This workflow deletes one or more regions. It's used by the
 * [Delete Region Admin API Route](https://docs.medusajs.com/api/admin#regions_deleteregionsid).
 *
 * You can use this workflow within your own customizations or custom workflows, allowing you
 * to delete regions in your custom flows.
 *
 * @example
 * const { result } = await deleteRegionsWorkflow(container)
 * .run({
 *   input: {
 *     ids: ["reg_123"]
 *   }
 * })
 *
 * @summary
 *
 * Delete one or more regions.
 */
exports.deleteRegionsWorkflow = (0, workflows_sdk_1.createWorkflow)(exports.deleteRegionsWorkflowId, (input) => {
    (0, steps_1.deleteRegionsStep)(input.ids);
    const regionIdEvents = (0, workflows_sdk_1.transform)({ input }, ({ input }) => {
        return input.ids?.map((id) => {
            return { id };
        });
    });
    (0, remove_remote_links_1.removeRemoteLinkStep)({
        [utils_1.Modules.REGION]: {
            region_id: input.ids,
        },
    });
    (0, emit_event_1.emitEventStep)({
        eventName: utils_1.RegionWorkflowEvents.DELETED,
        data: regionIdEvents,
    });
});
//# sourceMappingURL=delete-regions.js.map