import { FilterableSalesChannelProps, SalesChannelDTO, UpdateSalesChannelDTO } from "@medusajs/framework/types";
/**
 * The data to update sales channels.
 */
export type UpdateSalesChannelsWorkflowInput = {
    /**
     * The filters to select the sales channels to update.
     */
    selector: FilterableSalesChannelProps;
    /**
     * The data to update the sales channels.
     */
    update: UpdateSalesChannelDTO;
};
/**
 * The updated sales channels.
 */
export type UpdateSalesChannelsWorkflowOutput = SalesChannelDTO[];
export declare const updateSalesChannelsWorkflowId = "update-sales-channels";
/**
 * This workflow updates sales channels matching the specified conditions. It's used by the
 * [Update Sales Channel Admin API Route](https://docs.medusajs.com/api/admin#sales-channels_postsaleschannelsid).
 *
 * You can use this workflow within your customizations or your own custom workflows, allowing you to
 * update sales channels within your custom flows.
 *
 * @example
 * const { result } = await updateSalesChannelsWorkflow(container)
 * .run({
 *   input: {
 *     selector: {
 *       id: "sc_123"
 *     },
 *     update: {
 *       name: "Webshop"
 *     }
 *   }
 * })
 *
 * @summary
 *
 * Update sales channels.
 */
export declare const updateSalesChannelsWorkflow: import("@medusajs/framework/workflows-sdk").ReturnWorkflow<UpdateSalesChannelsWorkflowInput, UpdateSalesChannelsWorkflowOutput, []>;
//# sourceMappingURL=update-sales-channels.d.ts.map